Welcome to the **nufeb_tools** documentation.
=============================================


.. toctree::
   :maxdepth: 3
   :caption: Notes

   readme.rst
   license.rst


.. toctree::
   :maxdepth: 3
   :caption: Package Content

   atom_generation
   analysis
   datafed

.. toctree::
  :maxdepth: 3
  :caption: Examples

  examples

